/*
 * linux_mpeg2: drivers for the Visiontech/ BMK Kfir MPEG2 encoder card
 * Copyright (C) 1999,2000 convergence integrated media GmbH
 * 

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * Or, point your browser to http://www.gnu.org/copyleft/gpl.html
 * 

 * The author can be reached at ralph@convergence.de, 

 * the project's page is at http://linuxtv.org/mpeg2/
 */

#ifndef _KFIR_H_
#define _KFIR_H_

#define KFIR_MICRO_PATH "/lib/kfir/"

#ifdef __KERNEL__
/* For 2.2.x backwards compatibility */
#if LINUX_VERSION_CODE < 0x020300
#define net_device device
#define DECLARE_MUTEX(foo)         struct semaphore foo = MUTEX
#define DECLARE_MUTEX_LOCKED(foo)  struct semaphore foo = MUTEX_LOCKED
#define WAIT_QUEUE                 struct wait_queue*
#define init_waitqueue_head(wq)    *(wq) = NULL;
#define DECLARE_WAITQUEUE(wait, current) struct wait_queue wait = { current, NULL }
#define set_current_state(state_value)			\
	do { current->state = state_value; } while (0)
#else
#define WAIT_QUEUE                 wait_queue_head_t
#endif
#endif

//#include <stdint.h>
#include <linux/types.h>
#include <linux/ioctl.h>

typedef uint8_t  BYTE;
typedef uint16_t WORD;
typedef uint32_t DWORD;
typedef uint64_t QWORD;
typedef int bool;
typedef bool BOOL;

#include "Kfir.h"

#define VIDIOCGKFIRPARAMS _IOR('v',  BASE_VIDIOCPRIVATE+0, VT_KFIR_CParams)
#define VIDIOCSKFIRPARAMS _IOW('v',  BASE_VIDIOCPRIVATE+1, VT_KFIR_CParams)

#ifndef PCI_VENDOR_ID_VISIONTECH
#define PCI_VENDOR_ID_VISIONTECH		0x141f
#endif
#ifndef PCI_DEVICE_ID_VISIONTECH_KFIR_5E
#define PCI_DEVICE_ID_VISIONTECH_KFIR_5E	0x8000
#endif

#ifdef __KERNEL__

#define MAX_NUM_KFIR 8

#define wplxl(adr, dat)    writel((dat), (adr)+kfir->mem0)
#define rplxl(adr)         readl((adr)+kfir->mem0)

#define waltl(adr, dat)    writel((dat), kfir->AlteraReg+kfir->adr)
#define raltl(adr)         readl(kfir->AlteraReg+kfir->adr)

#define KfirRegWrite(adr, dat) (writel((dat), kfir->KfirReg+adr), udelay(10))
#define KfirRegRead(adr)       (udelay(10),readl(kfir->KfirReg+adr))

#define AlteraRegWrite(adr, dat) (writel((dat), kfir->AlteraReg+adr), udelay(10))
#define AlteraRegRead(adr)       (udelay(10),readl(kfir->AlteraReg+adr))

#define ADSPWriteAddr(dat)  waltl(ALT_ADR_ADSP_ADDR, dat)
#define ADSPWriteData(dat)  waltl(ALT_ADR_ADSP_DATA, dat)
#define ADSPWriteIRQ(dat)   waltl(ALT_ADR_ADSP_IRQ, dat)
#define ADSPReadData  (0xffff&raltl(ALT_ADR_ADSP_DATA))


struct kfir_dev {
        struct video_device video;
        struct i2c_client *decoder;

        struct pci_dev *pdev;
        int mode;
        unsigned char revision;
        unsigned short subsystem_device;

        u8 *dmabuf;
        u8 *mpgbuf; 
#define MPGBUFSIZE 256*1024
  
        int readp;
        int writep;
        int recording;
	WAIT_QUEUE wq;
  
        unsigned char *mem0;
        unsigned char *mem1;
        unsigned char *mem2;
        unsigned char *mem3;

        unsigned char *KfirReg;
        unsigned char *AlteraReg;
          
        u32 ALT_ADR_INT_MASK;
        u32 ALT_ADR_INT_REG_CLR;
        u32 ALT_ADR_KFIR_AUDIO_BASE;
        u32 ALT_ADR_RESET_REG;

	u32 ALT_ADR_ADSP_ADDR;
	u32 ALT_ADR_ADSP_DATA;
	u32 ALT_ADR_ADSP_IRQ;
	u32 ALT_ADR_ADSP_FREQ;
	u32 ALT_ADR_I2C;
	u32 ALT_ADR_CONTROL_0;
	u32 ALT_ADR_CONTROL_1;
	u32 ALT_ADR_CLOCK_PADI;

	/* i2c */
	struct i2c_adapter         i2c_adap;
	struct i2c_algo_bit_data   i2c_algo;
	struct i2c_client          i2c_client;
        u32 i2c;
        int i2c_ok;

        int kfirreset;
        WORD m_CmdReg;
        int WasReset;
        int FlFirstTime;
        int FlValid;
        int FlStopVideo;
        int MajorVersion;
        int MinorVersion;
        int DVB_MODE;

        u32 *micro;
        int mp;
  
        WORD Par[KFIR_MAX_PARAMS];
        WORD MuxParams[MAX_MUX_PARAMS];
        u8 Table[ TRANSPORT_PACKET_SIZE ];
        VT_KFIR_CParams Params;
        KFIR_INT_REG KfState;
        QWORD TotalLinesAfterMUX;
        u32 IntVideoCnt;
        u32 IntAudioCnt;
        u32 IntVibCnt;
        int LastDMASize;
        u32 EventMask;
        u32 TotalLinessaved;
};

#endif /* __KERNEL__ */
#endif
